@@ -155,6 +155,9 @@ def _determine_user_agent():
         # sys.argv is empty, usually the Python interpreter prevents this.
         return None
 
+    if not name:
+        return None
+
     name = os.path.basename(name)
     if name in ignored:
         name = _determine_calling_package()
@@ -208,7 +211,7 @@ class Session(object):
 
     user_agent = None
 
-    _REDIRECT_STATUSES = (301, 302, 303, 305, 307)
+    _REDIRECT_STATUSES = (301, 302, 303, 305, 307, 308)
 
     _DEFAULT_REDIRECT_LIMIT = 30
 
