@@ -13,6 +13,7 @@
 import itertools
 import json
 import logging
+import sys
 import uuid
 
 import mock
@@ -133,6 +134,24 @@ class SessionTests(utils.TestCase):
         self.assertTrue(resp.ok)
         self.assertRequestHeaderEqual('User-Agent', 'overrides-agent')
 
+        # If sys.argv is an empty list, then doesn't fail.
+        with mock.patch.object(sys, 'argv', []):
+            session = client_session.Session()
+            resp = session.get(self.TEST_URL)
+            self.assertTrue(resp.ok)
+            self.assertRequestHeaderEqual(
+                'User-Agent',
+                client_session.DEFAULT_USER_AGENT)
+
+        # If sys.argv[0] is an empty string, then doesn't fail.
+        with mock.patch.object(sys, 'argv', ['']):
+            session = client_session.Session()
+            resp = session.get(self.TEST_URL)
+            self.assertTrue(resp.ok)
+            self.assertRequestHeaderEqual(
+                'User-Agent',
+                client_session.DEFAULT_USER_AGENT)
+
     def test_http_session_opts(self):
         session = client_session.Session(cert='cert.pem', timeout=5,
                                          verify='certs')
@@ -343,6 +362,12 @@ class RedirectTests(utils.TestCase):
             self.assertEqual(r.url, s.url)
             self.assertEqual(r.status_code, s.status_code)
 
+    def test_permanent_redirect_308(self):
+        session = client_session.Session()
+        self.setup_redirects(status_code=308)
+        resp = session.get(self.REDIRECT_CHAIN[-2])
+        self.assertResponse(resp)
+
 
 class AuthPlugin(plugin.BaseAuthPlugin):
     """Very simple debug authentication plugin.
@@ -443,7 +468,7 @@ class SessionAuthTests(utils.TestCase):
         auth = AuthPlugin()
         sess = client_session.Session(auth=auth)
         resp = sess.get(self.TEST_URL)
-        self.assertDictEqual(resp.json(), self.TEST_JSON)
+        self.assertEqual(resp.json(), self.TEST_JSON)
 
         self.assertRequestHeaderEqual('X-Auth-Token', AuthPlugin.TEST_TOKEN)
 
@@ -453,7 +478,7 @@ class SessionAuthTests(utils.TestCase):
         auth = AuthPlugin()
         sess = client_session.Session(auth=auth)
         resp = sess.get(self.TEST_URL, authenticated=False)
-        self.assertDictEqual(resp.json(), self.TEST_JSON)
+        self.assertEqual(resp.json(), self.TEST_JSON)
 
         self.assertRequestHeaderEqual('X-Auth-Token', None)
 
